==> arcana-0.2.7.tar.gz: arcana-0.2.7/arcana/exceptions.py <==
class ArcanaException(Exception):
    pass


class ArcanaError(ArcanaException):
    pass


class ArcanaVersionError(ArcanaError):
    pass


class ArcanaRequirementNotFoundError(ArcanaVersionError):
    pass


class ArcanaVersionNotDectableError(ArcanaVersionError):
    pass


class ArcanaEnvModuleNotLoadedError(ArcanaError):
    pass


class ArcanaMissingInputError(ArcanaException):
    pass


class ArcanaProtectedOutputConflictError(ArcanaError):
    pass


class ArcanaCantPickleStudyError(ArcanaError):
    pass


class ArcanaBadlyFormattedDirectoryRepositoryError(ArcanaError):
    pass


class ArcanaUsageError(ArcanaError):
    pass


class ArcanaDesignError(ArcanaError):
    pass


class ArcanaNameError(ArcanaError):

    def __init__(self, name, msg):
        super(ArcanaNameError, self).__init__(msg)
        self.name = name


class ArcanaIndexError(ArcanaError):

    def __init__(self, index, msg):
        super(ArcanaIndexError, self).__init__(msg)
        self.index = index


class ArcanaMissingDataException(ArcanaError):
    pass


class ArcanaDataNotDerivedYetError(ArcanaError):
    pass


class ArcanaFilesetSelectorError(ArcanaUsageError):
    pass


class ArcanaOutputNotProducedException(ArcanaException):
    """
    Raised when a given spec is not produced due to switches and inputs
    provided to the study
    """


class ArcanaFileFormatError(ArcanaError):
    pass


class ArcanaFilesetNotCachedException(ArcanaException):
    pass


class AcquiredComponentException(ArcanaException):
    pass


class NoMatchingPipelineException(ArcanaException):
    pass


class ArcanaModulesNotInstalledException(ArcanaException):
    pass


class ArcanaJobSubmittedException(ArcanaException):
    """
    Signifies that a pipeline has been submitted to a scheduler and
    a return value won't be returned.
    """


class ArcanaNoRunRequiredException(ArcanaException):
    """
    Used to signify when a pipeline doesn't need to be run as all
    required outputs are already present in the repository
    """


class ArcanaFileFormatClashError(ArcanaError):
    """
    Used when two mismatching data formats are registered with the same
    name or extention
    """


class ArcanaNoConverterError(ArcanaError):
    "No converters exist between formats"


class ArcanaConverterNotAvailableError(ArcanaError):
    "The converter required to convert between formats is not "
    "available"


class ArcanaFileFormatNotRegisteredError(ArcanaError):
    pass


class ArcanaProvenanceRecordMismatchError(ArcanaError):
    pass


class ArcanaWrongRepositoryError(ArcanaError):
    pass

==> arcana-0.2.9.tar.gz: arcana-0.2.9/arcana/exceptions.py <==
class ArcanaException(Exception):
    pass


class ArcanaError(ArcanaException):
    pass


class ArcanaVersionError(ArcanaError):
    pass


class ArcanaRequirementNotFoundError(ArcanaVersionError):
    pass


class ArcanaVersionNotDectableError(ArcanaVersionError):
    pass


class ArcanaEnvModuleNotLoadedError(ArcanaError):
    pass


class ArcanaMissingInputError(ArcanaException):
    pass


class ArcanaProtectedOutputConflictError(ArcanaError):
    pass


class ArcanaCantPickleStudyError(ArcanaError):
    pass


class ArcanaBadlyFormattedDirectoryRepositoryError(ArcanaError):
    pass


class ArcanaUsageError(ArcanaError):
    pass


class ArcanaDesignError(ArcanaError):
    pass


class NamedArcanaError(ArcanaError):

    def __init__(self, name, msg):
        super(NamedArcanaError, self).__init__(msg)
        self.name = name


class ArcanaNameError(NamedArcanaError):
    pass


class ArcanaIndexError(ArcanaError):

    def __init__(self, index, msg):
        super(ArcanaIndexError, self).__init__(msg)
        self.index = index


class ArcanaMissingDataException(ArcanaUsageError):
    pass


class ArcanaDataNotDerivedYetError(NamedArcanaError, ArcanaDesignError):
    pass


class ArcanaSelectorError(ArcanaUsageError):
    pass


class ArcanaSelectorMissingMatchError(ArcanaSelectorError):
    pass


class ArcanaOutputNotProducedException(ArcanaException):
    """
    Raised when a given spec is not produced due to switches and inputs
    provided to the study
    """


class ArcanaFileFormatError(ArcanaError):
    pass


class ArcanaFilesetNotCachedException(ArcanaException):
    pass


class AcquiredComponentException(ArcanaException):
    pass


class NoMatchingPipelineException(ArcanaException):
    pass


class ArcanaModulesNotInstalledException(ArcanaException):
    pass


class ArcanaJobSubmittedException(ArcanaException):
    """
    Signifies that a pipeline has been submitted to a scheduler and
    a return value won't be returned.
    """


class ArcanaNoRunRequiredException(ArcanaException):
    """
    Used to signify when a pipeline doesn't need to be run as all
    required outputs are already present in the repository
    """


class ArcanaFileFormatClashError(ArcanaError):
    """
    Used when two mismatching data formats are registered with the same
    name or extention
    """


class ArcanaNoConverterError(ArcanaError):
    "No converters exist between formats"


class ArcanaConverterNotAvailableError(ArcanaError):
    "The converter required to convert between formats is not "
    "available"


class ArcanaFileFormatNotRegisteredError(ArcanaError):
    pass


class ArcanaReprocessException(ArcanaException):
    pass


class ArcanaWrongRepositoryError(ArcanaError):
    pass
